aboutsummaryrefslogtreecommitdiffstats
path: root/src/jogl/classes/com/jogamp/graph/geom/Outline.java
diff options
context:
space:
mode:
Diffstat (limited to 'src/jogl/classes/com/jogamp/graph/geom/Outline.java')
-rw-r--r--src/jogl/classes/com/jogamp/graph/geom/Outline.java18
1 files changed, 9 insertions, 9 deletions
diff --git a/src/jogl/classes/com/jogamp/graph/geom/Outline.java b/src/jogl/classes/com/jogamp/graph/geom/Outline.java
index 272f92f37..b593c20be 100644
--- a/src/jogl/classes/com/jogamp/graph/geom/Outline.java
+++ b/src/jogl/classes/com/jogamp/graph/geom/Outline.java
@@ -80,7 +80,7 @@ public class Outline implements Comparable<Outline> {
winding = src.getWinding();
dirtyWinding = false;
for(int i=0; i<count; i++) {
- vertices.add( src.vertices.get(i).clone() );
+ vertices.add( src.vertices.get(i).copy() );
}
closed = src.closed;
bbox = new AABBox(src.bbox);
@@ -103,12 +103,12 @@ public class Outline implements Comparable<Outline> {
dirtyWinding = false;
if( enforce != had_winding ) {
for(int i=count-1; i>=0; --i) {
- vertices.add( src.vertices.get(i).clone() );
+ vertices.add( src.vertices.get(i).copy() );
}
winding = enforce;
} else {
for(int i=0; i<count; ++i) {
- vertices.add( src.vertices.get(i).clone() );
+ vertices.add( src.vertices.get(i).copy() );
}
}
closed = src.closed;
@@ -256,11 +256,11 @@ public class Outline implements Comparable<Outline> {
* Ensure this outline is closed.
* <p>
* Checks whether the last vertex equals to the first.
* If not equal, it either appends a clone of the first vertex
* or prepends a clone of the last vertex, depending on <code>closeTail</code>.
* </p>
* @param closeTail if true, a clone of the first vertex will be appended,
* otherwise a clone of the last vertex will be prepended.
* @return true if closing performed, otherwise false for NOP
*/
public final boolean setClosed(final boolean closeTail) {
@@ -270,9 +270,9 @@ public class Outline implements Comparable<Outline> {
final Vertex last = getLastVertex();
if( !first.getCoord().isEqual( last.getCoord() ) ) {
if( closeTail ) {
- vertices.add(first.clone());
+ vertices.add(first.copy());
} else {
- vertices.add(0, last.clone());
+ vertices.add(0, last.copy());
}
return true;
}
@@ -256,11 +256,11 @@ public class Outline implements Comparable<Outline> {
* <p>
* Checks whether the last vertex equals to the first.
- * If not equal, it either appends a clone of the first vertex
- * or prepends a clone of the last vertex, depending on <code>closeTail</code>.
+ * If not equal, it either appends a copy of the first vertex
+ * or prepends a copy of the last vertex, depending on <code>closeTail</code>.
* </p>
@@ -256,11 +256,11 @@ public class Outline implements Comparable<Outline> {
* </p>
- * @param closeTail if true, a clone of the first vertex will be appended,
- * otherwise a clone of the last vertex will be prepended.
+ * @param closeTail if true, a copy of the first vertex will be appended,
+ * otherwise a copy of the last vertex will be prepended.
* @return true if closing performed, otherwise false for NOP
*/